@@ -26,12 +26,21 @@ const kpErrors = {
     NO_GROUPS_FOUND: 16,
     CANNOT_CREATE_NEW_GROUP: 17,
     NO_VALID_UUID_PROVIDED: 18,
+    ACCESS_TO_ALL_ENTRIES_DENIED: 19,
     PASSKEYS_ATTESTATION_NOT_SUPPORTED: 20,
     PASSKEYS_CREDENTIAL_IS_EXCLUDED: 21,
     PASSKEYS_REQUEST_CANCELED: 22,
     PASSKEYS_INVALID_USER_VERIFICATION: 23,
     PASSKEYS_EMPTY_PUBLIC_KEY: 24,
     PASSKEYS_INVALID_URL_PROVIDED: 25,
+    PASSKEYS_ORIGIN_NOT_ALLOWED: 26,
+    PASSKEYS_DOMAIN_IS_NOT_VALID: 27,
+    PASSKEYS_DOMAIN_RPID_MISMATCH: 28,
+    PASSKEYS_NO_SUPPORTED_ALGORITHMS: 29,
+    PASSKEYS_WAIT_FOR_LIFETIMER: 30,
+    PASSKEYS_UNKNOWN_ERROR: 31,
+    PASSKEYS_INVALID_CHALLENGE: 32,
+    PASSKEYS_INVALID_USER_ID: 33,
 
     errorMessages: {
         0: { msg: tr('errorMessageUnknown') },
@@ -60,7 +69,14 @@ const kpErrors = {
         23: { msg: tr('errorMessagePasskeysInvalidUserVerification') },
         24: { msg: tr('errorMessagePasskeysEmptyPublicKey') },
         25: { msg: tr('errorMessagePasskeysInvalidUrlProvided') },
-        26: { msg: tr('errorMessagePasskeysResidentKeyNotSupported') },
+        26: { msg: tr('errorMessagePasskeysOriginNotAllowed') },
+        27: { msg: tr('errorMessagePasskeysDomainNotValid') },
+        28: { msg: tr('errorMessagePasskeysDomainRpIdMismatch') },
+        29: { msg: tr('errorMessagePasskeysNoSupportedAlgorithms') },
+        30: { msg: tr('errorMessagePasskeysWaitforLifeTimer') },
+        31: { msg: tr('errorMessagePasskeysUnknownError') },
+        32: { msg: tr('errorMessagePasskeysInvalidChallenge') },
+        33: { msg: tr('errorMessagePasskeysInvalidUserId') },
     },
 
     getError(errorCode) {
