@@ -6,6 +6,7 @@ const EXTENSION_NAME = 'KeePassXC-Browser';
 const IGNORE_NOTHING = 'ignoreNothing';
 const IGNORE_NORMAL = 'ignoreNormal';
 const IGNORE_AUTOSUBMIT = 'ignoreAutoSubmit';
+const IGNORE_PASSKEYS = 'ignorePasskeys';
 const IGNORE_FULL = 'ignoreFull';
 
 // Credential sorting options
@@ -61,6 +62,17 @@ const ManualFill = {
     BOTH: 2
 };
 
+const SitePreferences = {
+    ALLOW_IFRAMES: 'allowIframes',
+    IMPROVED_FIELD_DETECTION: 'improvedFieldDetection',
+    USERNAME_ONLY: 'usernameOnly',
+};
+
+// Returns a string with 'px' for CSS styles
+const Pixels = function(value) {
+    return String(value) + 'px';
+};
+
 const compareVersion = function(minimum, current, canBeEqual = true) {
     if (!minimum || !current || minimum?.indexOf('.') === -1 || current?.indexOf('.') === -1) {
         return false;
@@ -179,13 +191,23 @@ const getFileAndLine = function() {
 
 const getCurrentTab = async function() {
     const tabs = await browser.tabs.query({ active: true, currentWindow: true });
-    return tabs.length > 0 ? tabs[0] : undefined;
+    return tabs?.length > 0 ? tabs[0] : undefined;
+};
+
+// Check if element b is inside a
+const isElementInside = (a, b) => (b.x >= a.x && b.right <= a.right) && (b.y >= a.y && b.bottom <= a.bottom);
+
+// Check if two elements overlap
+const elementsOverlap = function(rect1, rect2) {
+    const overlaps = (a, b) => !(a.right < b.left || a.left > b.right || a.bottom < b.top || a.top > b.bottom);
+    return isElementInside(rect1, rect2) || overlaps(rect1, rect2);
 };
 
 // Exports for tests
 if (typeof module === 'object') {
     module.exports = {
         compareVersion,
+        elementsOverlap,
         matchesWithNodeName,
         siteMatch,
         slashNeededForUrl,
