@@ -100,6 +100,9 @@ kpxcSites.exceptionFound = function(identifier, field) {
     } else if (document.location.origin === 'https://id.atlassian.com' &&
                 Array.isArray(identifier) && identifier?.contains('password-field')) {
         return true;
+    } else if (document.location.origin === 'https://app.fastmail.com'
+        && identifier?.contains('u-space-y-5') && field?.id === 'v25') {
+        return true;
     }
 
     return false;
@@ -232,6 +235,20 @@ kpxcSites.popupExceptionFound = function(combinations) {
     return false;
 };
 
+/**
+ * Handles exceptions where a certain element is set as a popover, and it prevents input field detections.
+ * @param {object} elem     Popover element
+ * @returns {boolean}       True if exception found
+ */
+kpxcSites.overlayExceptionFound = function(elem) {
+    if (document.location.href?.startsWith('https://github.com/login')
+        && elem?.nodeName === 'TOOL-TIP' && elem?.baseURI === 'https://github.com/login') {
+        return true;
+    }
+
+    return false;
+};
+
 /**
  * Handles a few exceptions for certain sites where Username Icon is not placed properly.
  * @param {number} left         Absolute left position of the icon
