@@ -9,6 +9,7 @@ const MAX_SEGMENTED_FIELD_LENGTH = 100;
  * Provides methods for input field handling.
  */
 const kpxcFields = {};
+kpxcFields.popoverSupported = true;
 
 // Returns all username & password combinations detected from the inputs.
 // After username field is detected, first password field found after that will be saved as a combination.
@@ -29,7 +30,7 @@ kpxcFields.getAllCombinations = async function(inputs) {
                 form: input.form
             };
 
-            combinations.push(combination);
+            combinations.push(kpxcFields.getExistingCombination(combination));
             usernameField = null;
         } else if (kpxcTOTPIcons.isValid(input)) {
             // Dynamically added TOTP field
@@ -93,6 +94,26 @@ kpxcFields.getCombinationFromAllInputs = function() {
     return kpxc.combinations[0];
 };
 
+// Checks if existing combination is found and recognized fields are added to it
+kpxcFields.getExistingCombination = function(combination) {
+    // Lookup existing combinations that use the same form
+    const existingCombination = kpxc.combinations?.find(c => c.form === combination?.form);
+    if (existingCombination) {
+        // Replace values to the existing combination
+        existingCombination.username ??= combination.username;
+        existingCombination.password ??= combination.password;
+        if (existingCombination.passwordInputs?.length === 0) {
+            existingCombination.passwordInputs = combination.passwordInputs;
+        } else {
+            existingCombination.passwordInputs.push(combination.password);
+        }
+
+        return existingCombination;
+    }
+
+    return combination;
+};
+
 // Adds segmented TOTP fields to the combination if found
 kpxcFields.getSegmentedTOTPFields = function(inputs, combinations) {
     if (!kpxc.settings.showOTPIcon) {
@@ -413,11 +434,12 @@ kpxcFields.isSearchField = function(target) {
 
 // :popover-open selector is supported only with Firefox >= 125 and Chrome >= 114
 kpxcFields.discoverOverlays = function() {
-    try { 
+    try {
         kpxcFields.overlays = document.querySelectorAll(':popover-open, [popover]');
     } catch (e) {
         // Ignore SyntaxError (e.g., unsupported selector)
         if (!(e instanceof SyntaxError)) {
+            kpxcFields.popoverSupported = false;
             logError(e);
         }
     }
@@ -430,6 +452,7 @@ kpxcFields.hasOverlay = function(elem) {
     } catch (e) {
         // Ignore SyntaxError (e.g., unsupported selector)
         if (!(e instanceof SyntaxError)) {
+            kpxcFields.popoverSupported = false;
             logError(e);
         }
     }
@@ -472,6 +495,10 @@ kpxcFields.isTopElement = function(elem, rect) {
 
     // Check for popup overlays
     for (const overlay of kpxcFields.overlays ?? []) {
+        if (kpxcSites.overlayExceptionFound(overlay)) {
+            continue;
+        }
+
         const overlayRect = overlay?.getBoundingClientRect();
         if (overlayRect && elementsOverlap(rect, overlayRect)) {
             return false;
