@@ -62,10 +62,10 @@ kpxc.addToSitePreferences = async function(optionName, addWildcard = false) {
 
     await sendMessage('save_settings', kpxc.settings);
 
-    if (optionName === 'allowIframes') {
+    if (optionName === SitePreferences.ALLOW_IFRAMES) {
         await sendMessage('page_set_allow_iframes', [ true, site ]);
         await sendMessage('iframe_detected', false);
-    } else if (optionName === 'usernameOnly') {
+    } else if (optionName === SitePreferences.USERNAME_ONLY) {
         await sendMessage('username_field_detected', false);
     }
 };
@@ -519,7 +519,7 @@ kpxc.prepareCredentials = async function() {
     kpxc.initAutocomplete();
 
     if (kpxc.settings.autoFillRelevantCredential) {
-        const pageUuid = await sendMessage('page_get_login_id');
+        const pageUuid = await sendMessage('page_get_login_id', false);
         if (pageUuid) {
             const relevantCredential = kpxc.credentials.find(c => c.uuid === pageUuid);
             const combination = kpxc.combinations?.at(-1);
@@ -736,12 +736,20 @@ kpxc.setValue = function(field, value, forced = false) {
         field.checked = true;
     }
 
+    // Make sure the input is not wrapped inside another element (custom INPUT element)
+    if (field?.nodeName !== 'INPUT' && field?.nodeName?.includes('INPUT')) {
+        const childInput = field?.querySelector('input');
+        const fieldsFromShadowDOM = kpxcObserverHelper.findInputsFromShadowDOM(field);
+        field = childInput ?? fieldsFromShadowDOM[0];
+    }
+
+
     kpxc.setValueWithChange(field, value, forced);
 };
 
 // Sets a new value to input field and triggers necessary events
 kpxc.setValueWithChange = function(field, value, forced = false) {
-    if (!forced && field.readOnly) {
+    if (!field || (field?.readOnly && !forced)) {
         return;
     }
 
@@ -952,9 +960,9 @@ browser.runtime.onMessage.addListener(async function(req, sender) {
         if (req.action === 'activated_tab') {
             kpxc.triggerActivatedTab();
         } else if (req.action === 'add_allow_iframes_option') {
-            kpxc.addToSitePreferences('allowIframes');
+            kpxc.addToSitePreferences(SitePreferences.ALLOW_IFRAMES);
         } else if (req.action === 'add_username_only_option') {
-            kpxc.addToSitePreferences('usernameOnly', true);
+            kpxc.addToSitePreferences(SitePreferences.USERNAME_ONLY, true);
         } else if (req.action === 'check_database_hash' && 'hash' in req) {
             kpxc.detectDatabaseChange(req);
         } else if (req.action === 'choose_credential_fields') {
