@@ -7,6 +7,9 @@ const MIN_INPUT_FIELD_OFFSET_WIDTH = 60;
 const MIN_OPACITY = 0.7;
 const MAX_OPACITY = 1;
 
+const MIN_ICON_SIZE = 14;
+const MAX_ICON_SIZE = 24;
+
 const BLUE_BUTTON = 'kpxc-button kpxc-blue-button';
 const GREEN_BUTTON = 'kpxc-button kpxc-green-button';
 const ORANGE_BUTTON = 'kpxc-button kpxc-orange-button';
@@ -29,11 +32,6 @@ const $ = function(elem) {
     return document.querySelector(elem);
 };
 
-// Returns a string with 'px' for CSS styles
-const Pixels = function(value) {
-    return String(value) + 'px';
-};
-
 // Basic icon class
 class Icon {
     constructor(field, databaseState = DatabaseState.DISCONNECTED, segmented = false) {
@@ -52,6 +50,11 @@ class Icon {
         }
     }
 
+    // Size the icon dynamically, but not greater than 24 or smaller than 14
+    calculateIconSize(field) {
+        return Math.max(Math.min(MAX_ICON_SIZE, field.offsetHeight - 4), MIN_ICON_SIZE);
+    }
+
     // Creates a wrapper div that has the icon in Shadow DOM
     createWrapper(styleSheetFilename) {
         const styleSheet = createStylesheet(styleSheetFilename);
@@ -96,7 +99,11 @@ const kpxcUI = {};
 kpxcUI.mouseDown = false;
 
 if (document.body) {
-    kpxcUI.bodyRect = document.body.getBoundingClientRect();
+    const bodyRect = document.body.getBoundingClientRect();
+    kpxcUI.bodyRect = {
+        left: bodyRect.left + window.pageXOffset,
+        top: bodyRect.top + window.pageYOffset
+    };
     kpxcUI.bodyStyle = getComputedStyle(document.body);
 }
 
