@@ -1,6 +1,7 @@
 'use strict';
 
 const options = {};
+options.dropdownButton = null;
 
 const $ = function(elem) {
     return document.querySelector(elem);
@@ -536,6 +537,43 @@ options.initSitePreferences = function() {
         modalEvent.currentTarget.querySelector('.modal-footer button.yes').focus();
     });
 
+    const settingsButtonClicked = function(e) {
+        e.preventDefault();
+
+        const closestTr = e.target.closest('tr');
+        const url = closestTr.getAttribute('url');
+        const sitePreferences = options.settings['sitePreferences']?.find((pref) => pref?.url === url);
+        const usernameOnly = sitePreferences.usernameOnly;
+        const improvedFieldDetection = sitePreferences.improvedFieldDetection;
+        const allowIframes = sitePreferences.allowIframes;
+
+        const dropdown = $('.settings-dropdown');
+        if (dropdown?.style?.display !== 'block'
+            || (dropdown?.style?.display === 'block' && e.target !== options.dropdownButton)) {
+            if (options.dropdownButton) {
+                options.dropdownButton.classList.remove('active');
+                // Update number of enabled settings to the old Settings button
+                const checkboxValues = Array.from(dropdown?.querySelectorAll('input[type=checkbox]')).map(c => c.checked);
+                updateSettingsButtonText(options.dropdownButton, checkboxValues);
+            }
+
+            // Apply current settings to the dropdown
+            dropdown.querySelector('#usernameOnly').checked = usernameOnly;
+            dropdown.querySelector('#improvedFieldDetection').checked = improvedFieldDetection;
+            dropdown.querySelector('#allowIframes').checked = allowIframes;
+
+            dropdown?.show();
+            updateDropdownPosition(e, dropdown);
+            options.dropdownButton = e.target;
+            options.dropdownButton.classList.add('active');
+        } else {
+            dropdown?.hide();
+            options.dropdownButton.classList.remove('active');
+            updateSettingsButtonText(options.dropdownButton, [ usernameOnly, improvedFieldDetection, allowIframes ]);
+            options.dropdownButton = null;
+        }
+    };
+
     const removeButtonClicked = function(e) {
         e.preventDefault();
 
@@ -601,18 +639,18 @@ options.initSitePreferences = function() {
         }
     };
 
-    const checkboxClicked = function() {
-        const closestTr = this.closest('tr');
+    const checkboxClicked = async function(e) {
+        const closestTr = options?.dropdownButton?.closest('tr');
         const url = closestTr.getAttribute('url');
 
         for (const site of options.settings['sitePreferences']) {
             if (site.url === url) {
-                if (this.name === 'usernameOnly') {
-                    site.usernameOnly = this.checked;
-                } else if (this.name === 'improvedFieldDetection') {
-                    site.improvedFieldDetection = this.checked;
-                } else if (this.name === 'allowIframes') {
-                    site.allowIframes = this.checked;
+                if (e.target.name === SitePreferences.USERNAME_ONLY) {
+                    site.usernameOnly = e.target.checked;
+                } else if (e.target.name === SitePreferences.IMPROVED_FIELD_DETECTION) {
+                    site.improvedFieldDetection = e.target.checked;
+                } else if (e.target.name === SitePreferences.ALLOW_IFRAMES) {
+                    site.allowIframes = e.target.checked;
                 }
             }
         }
@@ -633,6 +671,11 @@ options.initSitePreferences = function() {
         options.saveSettings();
     };
 
+    const dropdown = $('.settings-dropdown');
+    dropdown.querySelector('#usernameOnly').addEventListener('change', checkboxClicked);
+    dropdown.querySelector('#improvedFieldDetection').addEventListener('change',checkboxClicked);
+    dropdown.querySelector('#allowIframes').addEventListener('change', checkboxClicked);
+
     const addNewRow = function(rowClone, newIndex, url, ignore, usernameOnly, improvedFieldDetection, allowIframes) {
         const row = rowClone.cloneNode(true);
         row.setAttribute('url', url);
@@ -662,19 +705,25 @@ options.initSitePreferences = function() {
             saveModifiedUrl(e, row, inputField, editButton, cancelButton, saveButton)
         );
 
+        // Page URL
         row.children[0].children[0].children[0].value = url;
         row.children[0].children[0]?.addEventListener('dblclick', (e) => 
             enterEditMode(e, row, inputField, editButton, cancelButton, saveButton)
         );
-        row.children[1].children[0].value = ignore;
-        row.children[1].children[0].addEventListener('change', selectionChanged);
-        row.children[2].children['usernameOnly'].checked = usernameOnly;
-        row.children[2].children['usernameOnly'].addEventListener('change', checkboxClicked);
-        row.children[3].children['improvedFieldDetection'].checked = improvedFieldDetection;
-        row.children[3].children['improvedFieldDetection'].addEventListener('change', checkboxClicked);
-        row.children[4].children['allowIframes'].checked = allowIframes;
-        row.children[4].children['allowIframes'].addEventListener('change', checkboxClicked);
-        row.children[5].addEventListener('click', removeButtonClicked);
+
+        // Settings
+        const settings = row.children[1];
+        updateSettingsButtonText(settings.querySelector('#settings-button'),
+            [ usernameOnly, improvedFieldDetection, allowIframes ]);
+        settings.querySelector('#settings-button').addEventListener('click', (e) => settingsButtonClicked(e));
+
+        // Ignore
+        const ignoreSelect = row.children[2];
+        ignoreSelect.querySelector('#ignore-select').value = ignore;
+        ignoreSelect.querySelector('#ignore-select').addEventListener('change', selectionChanged);
+
+        // Remove button
+        row.children[3].addEventListener('click', removeButtonClicked);
 
         $('#tab-site-preferences table tbody').append(row);
     };
@@ -738,11 +787,11 @@ options.initSitePreferences = function() {
         $('#tab-site-preferences table tbody tr.empty').hide();
 
         options.settings['sitePreferences'].push({
-            url: value,
-            ignore: IGNORE_NOTHING,
-            usernameOnly: false,
-            improvedFieldDetection: false,
             allowIframes: false,
+            ignore: IGNORE_NOTHING,
+            improvedFieldDetection: false,
+            url: value,
+            usernameOnly: false,
         });
         options.saveSettings();
         manualUrl.value = '';
@@ -777,7 +826,7 @@ options.initAbout = function() {
     $('#tab-about span.versionCIP').textContent = version;
     $('#tab-about span.kpxcbrVersion').textContent = version;
     $('#tab-about span.kpxcbrOS').textContent = platform;
-    $('#tab-about span.kpxcbrBrowser').textContent = getBrowserId();
+    $('#tab-about span.kpxcbrBrowser').textContent = getBrowserId(navigator.userAgent);
 };
 
 options.updateTheme = function() {
@@ -805,24 +854,102 @@ options.createWarning = function(elem, text) {
     }, 5000);
 };
 
-const getBrowserId = function() {
-    if (navigator.userAgent.indexOf('Firefox') > -1) {
-        return 'Mozilla Firefox ' + navigator.userAgent.substr(navigator.userAgent.lastIndexOf('/') + 1);
-    } else if (navigator.userAgent.indexOf('Edg') > -1) {
-        let startPos = navigator.userAgent.indexOf('Edg');
-        startPos = navigator.userAgent.indexOf('/', startPos) + 1;
-        const version = navigator.userAgent.substring(startPos);
-        return 'Microsoft Edge ' + version;
-    } else if (navigator.userAgent.indexOf('Chrome') > -1) {
-        let startPos = navigator.userAgent.indexOf('Chrome');
-        startPos = navigator.userAgent.indexOf('/', startPos) + 1;
-        const version = navigator.userAgent.substring(startPos, navigator.userAgent.indexOf('Safari'));
-        return 'Chrome/Chromium ' + version;
-    }
+const getBrowserId = function(userAgent) {
+    const browserQueries = [
+        { findStr: 'Firefox', name: 'Mozilla Firefox' },
+        { findStr: 'Edg', name: 'Microsoft Edge' },
+        { findStr: 'OPR', name: 'Opera' },
+        { findStr: 'Chrome', name: 'Chrome/Chromium' }
+    ];
 
+    const getVersion = (agent, findStr) => {
+        const match = agent?.match(new RegExp(`(?:${findStr})\/([\\d.]+)`));
+        return match ? match[1] : 'Unknown version';
+    };
+
+    for (const query of browserQueries) {
+        if (userAgent?.indexOf(query.findStr) > -1) {
+            return `${query.name} ${getVersion(userAgent, query.findStr)}`;
+        }
+    }
+  
     return 'Other/Unknown';
 };
 
+// Update the number of enabled settings to the button text
+const updateSettingsButtonText = function(buttonElement, enabledOptions = []) {
+    const numberOfEnabledOptions = enabledOptions.filter(o => o === true).length;
+    const buttonText = buttonElement.querySelector('span');
+
+    if (numberOfEnabledOptions > 0) {
+        buttonText.textContent =
+            `${browser.i18n.getMessage('optionsSitePreferencesSettings')} (${numberOfEnabledOptions})`;
+    } else {
+        buttonText.textContent = browser.i18n.getMessage('optionsSitePreferencesSettings');
+    }
+};
+
+// Updates settings dropdown menu position
+const updateDropdownPosition = function(e, dropdown) {
+    if (!dropdown) {
+        dropdown = $('.settings-dropdown');
+    }
+
+    const settingsButton = e?.target ?? options.dropdownButton;
+    const rect = settingsButton?.getClientRects()?.[0];
+    if (!rect) {
+        return;
+    }
+    
+    const zoom = getComputedStyle(document.body).zoom || 1;
+    const scrollTop = document.defaultView.scrollY / zoom;
+    const scrollLeft = document.defaultView?.scrollX / zoom;
+
+    // If dropdown does not fit to the bottom of the screen -> show it at the top of the settings button
+    const dropdownRect = dropdown.getBoundingClientRect();
+    const totalHeight = dropdownRect.height + rect.height;
+    const offset = (totalHeight + rect.y) / zoom > window.self.visualViewport.height ? totalHeight / zoom : 0;
+
+    dropdown.style.left = Pixels(rect.left / zoom + scrollLeft);
+    dropdown.style.top = Pixels(rect.bottom / zoom + scrollTop - offset);
+};
+
+// Hides the settings dropdown when clicked outside of it
+document.addEventListener('mouseup', function(e) {
+    if (!e.isTrusted) {
+        return;
+    }
+
+    const dropdown = $('.settings-dropdown');
+    if (dropdown?.style?.display !== 'block') {
+        return;
+    }
+
+    const rect = dropdown?.getClientRects()?.[0];
+    if (!rect) {
+        return;
+    }
+
+    if ((e.x > rect.right || e.x < rect.x) || (e.y > rect.bottom || e.y < rect.y)
+        && e.target.nodeName !== 'BUTTON') {
+        dropdown?.hide();
+        const checkboxValues = Array.from(dropdown?.querySelectorAll('input[type=checkbox]')).map(c => c.checked);
+        updateSettingsButtonText(options.dropdownButton, checkboxValues);
+        options.dropdownButton.classList.remove('active');
+        options.dropdownButton = null;
+    }
+});
+
+// Handle dropdown position on window resize
+window.addEventListener('resize', function() {
+    updateDropdownPosition();
+});
+
+// Handle dropdown position on scroll
+window.addEventListener('scroll', function() {
+    updateDropdownPosition();
+});
+
 (async() => {
     try {
         // We eagerly load the theme here to avoid a white flash
